Learn R Programming

wmwm (version 1.0.0)

wmwm-package: wmwm: Performs Wilcoxon-Mann-Whitney Test with Missing Data

Description

Performs Wilcoxon-Mann-Whitney test in the presence of missing data with controlled Type I error regardless of the values of missing data.

Arguments

Author

Maintainer: Yijin Zeng yijinzeng98@gmail.com [copyright holder]

Authors: